The goal of this project is to compare all permutations in a given list of language-library-compiler combos 
exhaustively to identify which combination works best for a specific end device. (Changes could be there 
due to os, hardware, gpu, library version, compiler version etc)

The idea is primarily to get me to write code and compare with my own eyes the difference across languages.

Another idea is to make it easier for clients to identify which combination is fastest in their local config
without writing these benchmarks themselves

Currently working on only Square Matrices(Floating point)